@@ -281,7 +281,7 @@ class TDependentModelHandle(ThermoModelHandle):
         for model in self._models:
             if model.indomain(T): return model.evaluate(T)
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
-                         f"at T={T:.2f} K", T=T, Tmin=self.Tmin, Tmax=self.Tmax)
+                         f"at T={T:.2f} K", chemical=self._chemical)
     
     at_T = __call__
     
@@ -293,7 +293,7 @@ class TDependentModelHandle(ThermoModelHandle):
         for model in self._models:
             if model.indomain(T): return model.differentiate_by_T(T, dT=dT)
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
-                         f"at T={T:.2f} K", T=T, Tmin=self.Tmin, Tmax=self.Tmax)
+                         f"at T={T:.2f} K", chemical=self._chemical)
         
     def differentiate_by_P(self, T, P=None, dP=1e-12):
         return 0
@@ -317,8 +317,7 @@ class TDependentModelHandle(ThermoModelHandle):
                 integral += model.integrate_by_T(Tmin, Tb)
                 Tb = Tmin
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
-                         f"between T={Ta:.2f} to {Tb:.2f} K", Ta=Ta, Tb=Tb,
-                         Tmin=self.Tmin, Tmax=self.Tmax)
+                         f"between T={Ta:.2f} to {Tb:.2f} K", chemical=self._chemical)
     
     def integrate_by_P(self, Pa, Pb, T):
         return (Pb - Pa) * self(T)
@@ -342,8 +341,7 @@ class TDependentModelHandle(ThermoModelHandle):
                 integral += model.integrate_by_T_over_T(Tmin, Tb)
                 Tb = Tmin
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
-                         f"between T={Ta:.2f} to {Tb:.2f} K", Ta=Ta, Tb=Tb,
-                         Tmin=self.Tmin, Tmax=self.Tmax)
+                         f"between T={Ta:.2f} to {Tb:.2f} K", chemical=self._chemical)
     
     
 class TPDependentModelHandle(ThermoModelHandle):
@@ -366,9 +364,7 @@ class TPDependentModelHandle(ThermoModelHandle):
         for model in self._models:
             if model.indomain(T, P): return model.evaluate(T, P)
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
-                          f"at T={T:.2f} K and P={P:.0f} Pa", T=T, P=P,
-                          Tmin=self.Tmin, Tmax=self.Tmax, 
-                          Pmin=self.Pmin, Pmax=self.Pmax)
+                          f"at T={T:.2f} K and P={P:.0f} Pa", chemical=self._chemical)
 
     def at_T(self, T):
         isa = isinstance
@@ -376,8 +372,7 @@ class TPDependentModelHandle(ThermoModelHandle):
             if isa(model, TDependentModel) and model.indomain(T):
                 return model.evaluate(T)
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
-                          f"at T={T:.2f} K", T=T,
-                          Tmin=self.Tmin, Tmax=self.Tmax)
+                          f"at T={T:.2f} K", chemical=self._chemical)
 
     def try_out(self, T, P):
         for model in self._models:
@@ -387,17 +382,13 @@ class TPDependentModelHandle(ThermoModelHandle):
         for model in self._models:
             if model.indomain(T, P): return model.differentiate_by_T(T, P)
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
-                          f"at T={T:.2f} K and P={P:.0f} Pa", T=T, P=P,
-                          Tmin=self.Tmin, Tmax=self.Tmax, 
-                          Pmin=self.Pmin, Pmax=self.Pmax)
+                          f"at T={T:.2f} K and P={P:.0f} Pa", chemical=self._chemical)
             
     def differentiate_by_P(self, T, P):
         for model in self._models:
              if model.indomain(T, P): return model.differentiate_by_P(T, P)
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
-                          f"at T={T:.2f} K and P={P:.0f} Pa", T=T, P=P,
-                          Tmin=self.Tmin, Tmax=self.Tmax, 
-                          Pmin=self.Pmin, Pmax=self.Pmax)
+                          f"at T={T:.2f} K and P={P:.0f} Pa", chemical=self._chemical)
 
     def integrate_by_T(self, Ta, Tb, P):
         integral = 0
@@ -419,8 +410,7 @@ class TPDependentModelHandle(ThermoModelHandle):
                 Tb = Tmin
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                           f"between T={Ta:.2f} to {Tb:.2f} K at P={P:.0f} Pa",
-                          Ta=Ta, Tb=Tb, P=P, Tmin=self.Tmin, Tmax=self.Tmax, 
-                          Pmin=self.Pmin, Pmax=self.Pmax)
+                          chemical=self._chemical)
     
     def integrate_by_P(self, Pa, Pb, T):
         integral = 0
@@ -443,8 +433,7 @@ class TPDependentModelHandle(ThermoModelHandle):
                 Pb = Pmin
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                           f"between P={Pa:5g} to {Pb:5g} Pa ast T={T:.2f}",
-                          Pa=Pa, Pb=Pb, T=T, Tmin=self.Tmin, Tmax=self.Tmax, 
-                          Pmin=self.Pmin, Pmax=self.Pmax)
+                          chemical=self._chemical)
     
     def integrate_by_T_over_T(self, Ta, Tb, P):
         integral = 0
@@ -467,8 +456,7 @@ class TPDependentModelHandle(ThermoModelHandle):
                 Tb = Tmin
         raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                           f"between T={Ta:.2f} to {Tb:.2f} K",
-                          Ta=Ta, Tb=Tb, P=P, Tmin=self.Tmin, Tmax=self.Tmax, 
-                          Pmin=self.Pmin, Pmax=self.Pmax)
+                          chemical=self._chemical)
         
             
     
\ No newline at end of file
