@@ -1,23 +1,23 @@
 # -*- coding: utf-8 -*-
+# BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
+# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# 
+# This module is under the UIUC open-source license. See 
+# github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
+# for license details.
 """
-Created on Thu Nov 28 22:59:17 2019
-
-@author: yoelr
 """
 from . import chemicals_user
 from . import thermo_user
 from . import read_only
 from . import registered
-from . import speed_up
 
 __all__ = (*chemicals_user.__all__,
            *thermo_user.__all__,
            *read_only.__all__,
-           *registered.__all__,
-           *speed_up.__all__)
+           *registered.__all__)
 
 from .registered import *
 from .chemicals_user import *
 from .thermo_user import *
-from .read_only import *
-from .speed_up import *
\ No newline at end of file
+from .read_only import *
\ No newline at end of file
